Compute the closeness centrality measures of the vertices in a weighted and directed network represented through its adjacency matrix.
closeness_c(
adj,
alpha = 1,
mode = "out",
method = "harmonic",
distance = FALSE
)a list of node names and associated closeness centrality measures
is an adjacency matrix of a weighted and directed network
is a tuning parameter. The value of alpha must be nonnegative. By convention, alpha takes a value from 0 to 1 (default).
which mode to compute: "out" (default) or "in"? For undirected networks, this setting is irrelevant.
which method to use: "harmonic" (default) or "standard"?
whether to consider the entries in the adjacency matrix as
distances or strong connections. The default setting is FALSE.
Dijkstra, E.W. (1959). A note on two problems in connexion with graphs. Numerische Mathematik, 1, 269--271.
Newman, M.E.J. (2003). The structure and function of complex networks. SIAM review, 45(2), 167--256.
Opsahl, T., Agneessens, F., Skvoretz, J. (2010). Node centrality in weighted networks: Generalizing degree and shortest paths. Social Networks, 32, 245--251.
Zhang, P., Zhao, J. and Yan, J. (2020+) Centrality measures of networks with application to world input-output tables