Learn R Programming

wdnet (version 1.2.3)

cvxr_control: Parameters passed to CVXR::solve().

Description

Defined for the convex optimization problems for solving eta.

Usage

cvxr_control(
  solver = "ECOS",
  ignore_dcp = FALSE,
  warm_start = FALSE,
  verbose = FALSE,
  parallel = FALSE,
  gp = FALSE,
  feastol = 1e-05,
  reltol = 1e-05,
  abstol = 1e-05,
  num_iter = NULL,
  ...
)

Value

A list containing the parameters.

Arguments

solver

(Optional) A string indicating the solver to use. Defaults to "ECOS".

ignore_dcp

(Optional) A logical value indicating whether to override the DCP check for a problem.

warm_start

(Optional) A logical value indicating whether the previous solver result should be used to warm start.

verbose

(Optional) A logical value indicating whether to print additional solver output.

parallel

(Optional) A logical value indicating whether to solve in parallel if the problem is separable.

gp

(Optional) A logical value indicating whether the problem is a geometric program. Defaults to FALSE.

feastol

The feasible tolerance on the primal and dual residual. Defaults to 1e-5.

reltol

The relative tolerance on the duality gap. Defaults to 1e-5.

abstol

The absolute tolerance on the duality gap. Defaults to 1e-5.

num_iter

The maximum number of iterations.

...

Additional options that will be passed to the specific solver. In general, these options will override any default settings imposed by CVXR.

Examples

Run this code
control <- cvxr_control(solver = "OSQP", abstol = 1e-5)

Run the code above in your browser using DataLab