Learn R Programming

wdnet (version 1.2.3)

dw_assort: Compute the assortativity coefficient of a weighted and directed network.

Description

Compute the assortativity coefficient of a weighted and directed network.

Usage

dw_assort(adj, type = c("outin", "inin", "outout", "inout"))

Value

a scalar of assortativity coefficient

Arguments

adj

is an adjacency matrix of a weighted and directed network.

type

which type of assortativity coefficient to compute: "outin" (default), "inin", "outout" or "inout"?

References

  • Foster, J.G., Foster, D.V., Grassberger, P. and Paczuski, M. (2010). Edge direction and the structure of networks. Proceedings of the National Academy of Sciences of the United States, 107(24), 10815--10820.

  • Yuan, Y. Zhang, P. and Yan, J. (2021). Assortativity coefficients for weighted and directed networks. Journal of Complex Networks, 9(2), cnab017.