dw_feature_assort: Feature based assortativity coefficient
Description
Node feature based assortativity coefficients for weighted and directed
networks.
Usage
dw_feature_assort(netwk, f1, f2)
Value
Directed weighted assortativity coefficients between source nodes'
f1 (or f2) and target nodes' f2(or f1).
Arguments
netwk
A wdnet object that represents the network.
f1
A vector, represents the first feature of existing nodes. Number of
nodes = length(f1) = length(f2). Defined for directed networks. If
NULL, out-strength will be used.
f2
A vector, represents the second feature of existing nodes. Defined
for directed networks. If NULL, in-strength will be used.