Learn R Programming

wdnet (version 1.2.3)

get_eta_undirected: Compute edge-level distribution for undirected networks with respect to desired assortativity level.

Description

Compute edge-level distribution for undirected networks with respect to desired assortativity level.

Usage

get_eta_undirected(
  edgelist,
  target.assortcoef = NULL,
  eta.obj = function(x) 0,
  control = cvxr_control()
)

Value

Assortativity level and corresponding edge-level distribution.

Arguments

edgelist

A two column matrix representing the undirected edges of a network.

target.assortcoef

Numeric, represents the predetermined assortativity coefficient. If NULL, the range of assortativity coefficient and corresponding joint distribution are returned.

eta.obj

A convex function of eta to be minimized when target.assortcoef is not NULL. Defaults to 0.

control

A list of parameters passed to CVXR::solve() when solving for eta or computing the range of assortativity coefficient.