These functions print a network to the terminal.
# S3 method for wdnet
print(x, node.attrs = TRUE, edge.attrs = TRUE, max.lines = 5, ...)# S3 method for wdnet
summary(object, ...)
A wdnet object.
Logical, whether to print node attributes, if available.
Logical, whether to print edge attributes, if available.
Integer, the maximum number of lines of edgelist and node attributes to print. The rest of the output will be truncated.
Additional arguments.
The graph of which the summary will be printed.
summary.wdnet prints the number of nodes and edges, preference
functions, and whether the network is directed, weighted. print.wdnet
prints the same information, and also lists some edges and node attributes,
if available. Edge scenarios are 0: from initial network; 1: alpha; 2:
beta; 3: gamma; 4: xi; 5; rho; 6: reciprocal.