A list of class rpacontrol with components sampler,
snode.replace, tnode.replace and node.replace with
meanings as explained under 'Arguments'.
Arguments
sampler
A function used for sampling the number of new edges to be
added at each step. If NULL, one new edge will be added at each
step. If a function is provided, it must accept a single argument,
n, and return a vector of length n that represents the
sampled number of new edges.
snode.replace
Logical. Determines whether the source nodes in the same
step should be sampled with replacement. Defined for directed networks.
tnode.replace
Logical. Determines whether the target nodes in the same
step should be sampled with replacement. Defined for directed networks.
node.replace
Logical. Determines whether the nodes in the same step
should be sampled with replacement. Defined for undirected networks. If
FALSE, self-loops will not be allowed under beta scenario.