A list of class rpacontrol with components group.prob,
recip.prob, and selfloop.recip with meanings as explained
under 'Arguments'.
Arguments
group.prob
A vector of probability weights for sampling the group of
new nodes. Defined for directed networks. Groups are from 1 to
length(group.prob). Its length must equal to the number of rows of
recip.prob.
recip.prob
A square matrix giving the probability of adding a
reciprocal edge after a new edge is introduced. Defined for directed
networks. Its element p_{ij} represents the probability of adding a
reciprocal edge from node A, which belongs to group i, to
node B, which belongs to group j, immediately after a
directed edge from B to A is added.
selfloop.recip
Logical, whether reciprocal edge of self-loops are
allowed.