source.first with meanings as explained under 'Arguments'.
Arguments
alpha
Probability of adding an edge from a new node to an existing
node.
beta
Probability of adding an edge between existing nodes.
gamma
Probability of adding an edge from an existing node to a new
node.
xi
Probability of adding an edge between two new nodes.
rho
Probability of adding a new node with a self-loop.
beta.loop
Logical. Determines whether self-loops are allowed under the
beta scenario. Default value is TRUE.
source.first
Logical. Defined for beta scenario edges of
directed networks. If TRUE, the source node of a new edge is sampled
from existing nodes before the target node is sampled; if FALSE, the
target node is sampled from existing nodes before the source node is
sampled. Default value is TRUE.