These functions generate a PA network with linear (rpanet_simple) or
non-linear (rpanet_general) preference functions
rpanet_general(
nstep,
initial.network,
control,
m,
sum_m,
w,
nnode,
nedge,
method,
sample.recip
)rpanet_simple(
nstep,
initial.network,
control,
m,
sum_m,
w,
ex_node,
ex_edge,
method
)
Returns a wdnet object that includes the following components:
directed: Logical, whether the network is directed.
weighted: Logical, whether the network is weighted.
edgelist: A two-column matrix representing the edges.
edge.attr: A data frame including edge weights and edge
scenarios (0: from initial network; 1: alpha; 2: beta;
3: gamma; 4: xi; 5; rho; 6: reciprocal edge).
node.attr: A data frame including node out- and
in-strength, node source and target preference scores (for directed
networks), node strength and preference scores (for undirected
networks), and node group (if applicable).
newedge: The number of new edges at each step, including
reciprocal edges.
control: An rpacontrol object that is used to
generate the network.
Number of steps when generating a network.
A wdnet object or a list that represents the
initial network. By default, initial.network has one directed edge from node 1
to node 2 with weight 1. It may have the following components: a two-column
matrix edgelist representing the edges; a vector edgeweight
representing the weight of edges; a logical argument directed indicating
whether the initial network is directed;
an integer vector nodegroup
representing the group of nodes. nodegroup is defined for directed
networks, if NULL, all nodes from the seed network are considered
from group 1.
A list of parameters that controls the PA generation process.
The default value is wdnet:::rpa_control_default(). By default, in
each step, a new edge of weight 1 is added from a new node A to an
existing node B (alpha scenario), where $B is chosen
with probability proportional to its in-strength + 1.
Integer vector, number of new edges in each step.
Integer, summation of m.
Vector, weight of new edges.
Integer, number of nodes in initial.network.
Integer, number of edges in initial.network.
Which method to use when generating PA networks: "binary" or "linear".
Whether reciprocal edges will be added.