Defined for the convex optimization problems for solving eta.
cvxr_control(
solver = "ECOS",
ignore_dcp = FALSE,
warm_start = FALSE,
verbose = FALSE,
parallel = FALSE,
gp = FALSE,
feastol = 1e-05,
reltol = 1e-05,
abstol = 1e-05,
num_iter = NULL,
...
)A list containing the parameters.
(Optional) A string indicating the solver to use. Defaults to "ECOS".
(Optional) A logical value indicating whether to override the DCP check for a problem.
(Optional) A logical value indicating whether the previous solver result should be used to warm start.
(Optional) A logical value indicating whether to print additional solver output.
(Optional) A logical value indicating whether to solve in parallel if the problem is separable.
(Optional) A logical value indicating whether the problem is a geometric program. Defaults to FALSE.
The feasible tolerance on the primal and dual residual. Defaults to 1e-5.
The relative tolerance on the duality gap. Defaults to 1e-5.
The absolute tolerance on the duality gap. Defaults to 1e-5.
The maximum number of iterations.
Additional options that will be passed to the specific solver. In general, these options will override any default settings imposed by CVXR.
control <- cvxr_control(solver = "OSQP", abstol = 1e-5)
Run the code above in your browser using DataLab