Compute the assortativity coefficient of a weighted and directed network.
dw_assort(adj, type = c("outin", "inin", "outout", "inout"))a scalar of assortativity coefficient
is an adjacency matrix of a weighted and directed network.
which type of assortativity coefficient to compute: "outin" (default), "inin", "outout" or "inout"?
Foster, J.G., Foster, D.V., Grassberger, P. and Paczuski, M. (2010). Edge direction and the structure of networks. Proceedings of the National Academy of Sciences of the United States, 107(24), 10815--10820.
Yuan, Y. Zhang, P. and Yan, J. (2021). Assortativity coefficients for weighted and directed networks. Journal of Complex Networks, 9(2), cnab017.