Compute edge-level distribution for undirected networks with respect to desired assortativity level.
get_eta_undirected(
edgelist,
target.assortcoef = NULL,
eta.obj = function(x) 0,
control = cvxr_control()
)Assortativity level and corresponding edge-level distribution.
A two column matrix representing the undirected edges of a network.
Numeric, represents the predetermined assortativity
coefficient. If NULL, the range of assortativity coefficient and
corresponding joint distribution are returned.
A convex function of eta to be minimized when
target.assortcoef is not NULL. Defaults to 0.
A list of parameters passed to CVXR::solve() when
solving for eta or computing the range of assortativity coefficient.