rpa_control_edgeweight: Control weight of new edges. Defined for rpanet.
Description
Control weight of new edges. Defined for rpanet.
Usage
rpa_control_edgeweight(sampler = NULL)
Value
A list of class rpacontrol containing the sampler
function.
Arguments
sampler
A function used for sampling edge weights. If NULL, all
new edges will default to a weight of 1. If a function is provided, it must
accept a single argument, n, and return a vector of length n
that represents the sampled edge weights.